Betelgeuse
==========

.. image:: https://coveralls.io/repos/github/SatelliteQE/betelgeuse/badge.svg?branch=master
    :target: https://coveralls.io/github/SatelliteQE/betelgeuse?branch=master

.. image:: https://readthedocs.org/projects/betelgeuse/badge/?version=latest
    :target: http://betelgeuse.readthedocs.org/en/latest/?badge=latest
    :alt: Documentation Status

Betelgeuse reads standard Python test cases and offers tools to interact with
Polarion. Possible interactions are:

* Automatic creation and update of Requirements and Test Cases from a Python
  project code base.
* Creation of Test Runs based on a jUnit XML file.

The `full documentation <http://betelgeuse.readthedocs.org/en/latest/>`_ is
available on ReadTheDocs.
